# RelationReference

RelationReference represents a relation of a particular object type (e.g. 'document#viewer').

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** |  | 
**relation** | **str** |  | [optional] 
**wildcard** | **object** |  | [optional] 
**condition** | **str** | The name of a condition that is enforced over the allowed relation. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


